@@ -1,13 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .AbstractMapSettingContainer import *
+from typing import Generic
+from .MultiElementContainer import MultiElementContainer
+from .AbstractMapSettingContainer import AbstractMapSettingContainer
 
-T = TypeVar["T"]
+T = TypeVar("T")
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
-class AbstractMapSettingContainer_MapSettingEntry(MultiElementContainer):
+class AbstractMapSettingContainer_MapSettingEntry(Generic[T], MultiElementContainer):
 
 	@overload
 	def __init__(self, x: int, y: int, width: int, textRenderer: TextRenderer, parent: AbstractMapSettingContainer, key: str, value: T) -> None:
