@@ -1,12 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .MultiElementContainer import *
-from .AbstractSettingContainer import *
-from .SettingsOverlay_SettingField import *
+from typing import Generic
+from .MultiElementContainer import MultiElementContainer
+from .AbstractSettingContainer import AbstractSettingContainer
+from .SettingsOverlay_SettingField import SettingsOverlay_SettingField
 
+T = TypeVar("T")
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
-class AbstractSettingField(MultiElementContainer):
+class AbstractSettingField(Generic[T], MultiElementContainer):
 
 	@overload
 	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, parent: AbstractSettingContainer, field: SettingsOverlay_SettingField) -> None:
