@@ -1,18 +1,18 @@
 from typing import overload
 from typing import List
-from typing import TypeVar
 from typing import Mapping
-from .Core import *
-from .ScriptTrigger import *
-from .IEventListener import *
+from typing import Set
+from .Core import Core
+from .ScriptTrigger import ScriptTrigger
+from .IEventListener import IEventListener
 
-Set = TypeVar["java.util.Set_xyz.wagyourtail.jsmacros.core.event.IEventListener_"]
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
-Map = TypeVar["java.util.Map_java.lang.String,java.util.Set_xyz.wagyourtail.jsmacros.core.event.IEventListener__"]
 
 class BaseEventRegistry:
+	"""
+	Since: 1.2.7 
+	"""
 	oldEvents: Mapping[str, str]
-	events: List[str]
+	events: Set[str]
 
 	@overload
 	def __init__(self, runner: Core) -> None:
@@ -24,38 +24,88 @@ class BaseEventRegistry:
 
 	@overload
 	def addScriptTrigger(self, rawmacro: ScriptTrigger) -> None:
+		"""
+		Since: 1.1.2 [citation needed] 
+
+		Args:
+			rawmacro: 
+		"""
 		pass
 
 	@overload
 	def addListener(self, event: str, listener: IEventListener) -> None:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			listener: 
+			event: 
+		"""
 		pass
 
 	@overload
 	def removeListener(self, event: str, listener: IEventListener) -> bool:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			listener: 
+			event: 
+		"""
 		pass
 
 	@overload
 	def removeListener(self, listener: IEventListener) -> bool:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			listener: 
+		"""
 		pass
 
 	@overload
 	def removeScriptTrigger(self, rawmacro: ScriptTrigger) -> bool:
+		"""
+		Since: 1.1.2 [citation needed] 
+
+		Args:
+			rawmacro: 
+		"""
 		pass
 
 	@overload
-	def getListeners(self) -> Mapping[str, List[IEventListener]]:
+	def getListeners(self) -> Mapping[str, Set[IEventListener]]:
+		"""
+		Since: 1.2.3 
+		"""
 		pass
 
 	@overload
-	def getListeners(self, key: str) -> List[IEventListener]:
+	def getListeners(self, key: str) -> Set[IEventListener]:
+		"""
+		Since: 1.2.3 
+
+		Args:
+			key: 
+		"""
 		pass
 
 	@overload
 	def getScriptTriggers(self) -> List[ScriptTrigger]:
+		"""
+		Since: 1.1.2 [citation needed] 
+		"""
 		pass
 
 	@overload
 	def addEvent(self, eventName: str) -> None:
+		"""
+		Since: 1.1.2 [citation needed] 
+
+		Args:
+			eventName: 
+		"""
 		pass
 
 	@overload
