@@ -1,12 +1,14 @@
 from typing import overload
-from .IEventListener import *
-from .ScriptTrigger import *
-from .Core import *
-from .BaseEvent import *
-from .ContextContainer import *
+from .IEventListener import IEventListener
+from .ScriptTrigger import ScriptTrigger
+from .Core import Core
+from .BaseEvent import BaseEvent
+from .EventContainer import EventContainer
 
 
 class BaseListener(IEventListener):
+	"""This is for java-sided listeners, for creating listeners script sided directly use IEventListener
+	"""
 
 	@overload
 	def __init__(self, trigger: ScriptTrigger, runner: Core) -> None:
@@ -17,7 +19,7 @@ class BaseListener(IEventListener):
 		pass
 
 	@overload
-	def runScript(self, event: BaseEvent) -> ContextContainer:
+	def runScript(self, event: BaseEvent) -> EventContainer:
 		pass
 
 	@overload
