@@ -1,12 +1,12 @@
 from typing import overload
 from typing import TypeVar
-from .BaseWrappedException_SourceLocation import *
-from .BaseWrappedException import *
+from typing import Generic
+from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
 
-T = TypeVar["T"]
+T = TypeVar("T")
 StackTraceElement = TypeVar["java.lang.StackTraceElement"]
 
-class BaseWrappedException:
+class BaseWrappedException(Generic[T]):
 	stackFrame: T
 	location: BaseWrappedException_SourceLocation
 	message: str
