@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .BaseWrappedException_SourceLocation import *
+from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
 
 File = TypeVar["java.io.File"]
 
