@@ -42,7 +42,7 @@ class CancelScreen(BaseScreen):
 		pass
 
 	@overload
-	def onClose(self) -> None:
+	def close(self) -> None:
 		pass
 
 	pass
