@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .RunningContextContainer import *
+from .RunningContextContainer import RunningContextContainer
 
 Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.client.gui.containers.RunningContextContainer_"]
 
