@@ -3,7 +3,7 @@ from typing import TypeVar
 from .BaseHelper import BaseHelper
 from .TextHelper import TextHelper
 
-ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine_net.minecraft.text.Text_"]
+ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine"]
 ChatHud = TypeVar["net.minecraft.client.gui.hud.ChatHud"]
 
 class ChatHudLineHelper(BaseHelper):
@@ -16,10 +16,6 @@ class ChatHudLineHelper(BaseHelper):
 	def getText(self) -> TextHelper:
 		pass
 
-	@overload
-	def getId(self) -> int:
-		pass
-
 	@overload
 	def getCreationTick(self) -> int:
 		pass
