@@ -1,15 +1,12 @@
 from typing import overload
 from typing import List
-from typing import TypeVar
 from .MethodWrapper import MethodWrapper
 
-Function = TypeVar["java.util.function.Function_java.lang.String,xyz.wagyourtail.jsmacros.client.api.classes.CommandBuilder_"]
 
 class CommandBuilder:
 	"""
 	Since: 1.4.2 
 	"""
-	createNewBuilder: Function
 
 	@overload
 	def __init__(self) -> None:
