@@ -196,6 +196,16 @@ class EntityHelper(Generic[T], BaseHelper):
 		"""
 		pass
 
+	@overload
+	def setCustomNameVisible(self, b: bool) -> None:
+		"""sets the name to always display\n
+		Since: 1.8.0 
+
+		Args:
+			b: 
+		"""
+		pass
+
 	@overload
 	def setGlowingColor(self, color: int) -> None:
 		"""
