@@ -1,7 +1,6 @@
 from typing import overload
 from typing import TypeVar
 from typing import Generic
-from .BaseScriptContext import BaseScriptContext
 
 T = TypeVar("T")
 Runnable = TypeVar["java.lang.Runnable"]
@@ -13,7 +12,7 @@ class EventContainer(Generic[T]):
 	"""
 
 	@overload
-	def __init__(self, ctx: BaseScriptContext) -> None:
+	def __init__(self, ctx: T) -> None:
 		pass
 
 	@overload
@@ -25,7 +24,7 @@ class EventContainer(Generic[T]):
 		pass
 
 	@overload
-	def getCtx(self) -> BaseScriptContext:
+	def getCtx(self) -> T:
 		pass
 
 	@overload
