@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .ItemStackHelper import *
+from .BaseEvent import BaseEvent
+from .ItemStackHelper import ItemStackHelper
 
 ItemStack = TypeVar["net.minecraft.item.ItemStack"]
 
 class EventItemPickup(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	item: ItemStackHelper
 
 	@overload
