@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .MacroScreen import *
+from .MacroScreen import MacroScreen
 
 Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
 
