@@ -1,12 +1,15 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .PlayerListEntryHelper import *
+from .BaseEvent import BaseEvent
+from .PlayerListEntryHelper import PlayerListEntryHelper
 
 PlayerListEntry = TypeVar["net.minecraft.client.network.PlayerListEntry"]
 UUID = TypeVar["java.util.UUID"]
 
 class EventPlayerLeave(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	UUID: str
 	player: PlayerListEntryHelper
 
