@@ -1,9 +1,12 @@
 from typing import overload
-from .BaseEvent import *
-from .BaseProfile import *
+from .BaseEvent import BaseEvent
+from .BaseProfile import BaseProfile
 
 
 class EventProfileLoad(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	profileName: str
 
 	@overload
