@@ -1,11 +1,9 @@
 from typing import overload
 from typing import List
-from typing import TypeVar
-from .BaseEventRegistry import *
-from .Core import *
-from .ScriptTrigger import *
+from .BaseEventRegistry import BaseEventRegistry
+from .Core import Core
+from .ScriptTrigger import ScriptTrigger
 
-List = TypeVar["java.util.List_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
 
 class EventRegistry(BaseEventRegistry):
 
