@@ -1,9 +1,12 @@
 from typing import overload
-from .BaseEvent import *
-from .PositionCommon_Pos3D import *
+from .BaseEvent import BaseEvent
+from .PositionCommon_Pos3D import PositionCommon_Pos3D
 
 
 class EventSound(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	sound: str
 	volume: float
 	pitch: float
