@@ -1,11 +1,14 @@
 from typing import overload
 from typing import TypeVar
-from .BaseEvent import *
-from .TextHelper import *
+from .BaseEvent import BaseEvent
+from .TextHelper import TextHelper
 
 Text = TypeVar["net.minecraft.text.Text"]
 
 class EventTitle(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	type: str
 	message: TextHelper
 
