@@ -136,6 +136,104 @@ An instance of this class is passed to scripts as the 'JsMacros' variable.
 		"""
 		pass
 
+	@overload
+	def runScript(self, language: str, script: str, file: str, event: BaseEvent, callback: MethodWrapper) -> EventContainer:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			file: 
+			callback: 
+			language: 
+			event: 
+			script: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRun(self, file: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			file: 
+			T: 
+			U: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRun(self, language: str, script: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			T: 
+			U: 
+			language: 
+			script: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRun(self, language: str, script: str, file: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			file: 
+			T: 
+			U: 
+			language: 
+			script: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRunAsync(self, file: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			file: 
+			T: 
+			U: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRunAsync(self, language: str, script: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			T: 
+			U: 
+			language: 
+			script: 
+		"""
+		pass
+
+	@overload
+	def wrapScriptRunAsync(self, language: str, script: str, file: str) -> MethodWrapper:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			R: 
+			file: 
+			T: 
+			U: 
+			language: 
+			script: 
+		"""
+		pass
+
 	@overload
 	def open(self, path: str) -> None:
 		"""Opens a file with the default system program.\n
