@@ -1,15 +1,16 @@
 from typing import overload
-from .BaseLibrary import BaseLibrary
+from .PerExecLibrary import PerExecLibrary
+from .BaseScriptContext import BaseScriptContext
 
 
-class FTime(BaseLibrary):
+class FTime(PerExecLibrary):
 	"""Functions for getting and using raw java classes, methods and functions.
 
 An instance of this class is passed to scripts as the 'Time' variable.
 	"""
 
 	@overload
-	def __init__(self) -> None:
+	def __init__(self, context: BaseScriptContext) -> None:
 		pass
 
 	@overload
