@@ -5,9 +5,13 @@ from .BaseLibrary import BaseLibrary
 from .PlayerEntityHelper import PlayerEntityHelper
 from .PlayerListEntryHelper import PlayerListEntryHelper
 from .BlockDataHelper import BlockDataHelper
+from .PositionCommon_Pos3D import PositionCommon_Pos3D
+from .BlockPosHelper import BlockPosHelper
+from .WorldScannerBuilder import WorldScannerBuilder
+from .MethodWrapper import MethodWrapper
+from .WorldScanner import WorldScanner
 from .ScoreboardsHelper import ScoreboardsHelper
 from .EntityHelper import EntityHelper
-from .BlockPosHelper import BlockPosHelper
 from .BossBarHelper import BossBarHelper
 from .TextHelper import TextHelper
 
@@ -65,6 +69,112 @@ An instance of this class is passed to scripts as the 'World' variable.
 		"""
 		pass
 
+	@overload
+	def getBlock(self, pos: PositionCommon_Pos3D) -> BlockDataHelper:
+		pass
+
+	@overload
+	def getBlock(self, pos: BlockPosHelper) -> BlockDataHelper:
+		pass
+
+	@overload
+	def getWorldScanner(self) -> WorldScannerBuilder:
+		"""Usage: This will return all blocks that are facing south, don't require a tool to break, 
+have a hardness of 10 or less and whose name contains either chest or barrel. World.getWorldScanner()
+    .withBlockFilter("getHardness").is(" =", 10)
+    .andStringBlockFilter().contains("chest", "barrel")
+    .withStringStateFilter().contains("facing=south")
+    .andStateFilter("isToolRequired").is(false)
+    .build()\n
+		Since: 1.6.5 
+
+		Returns:
+			a builder to create a WorldScanner 
+		"""
+		pass
+
+	@overload
+	def getWorldScanner(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper) -> WorldScanner:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			a scanner for the current world 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, centerX: int, centerZ: int, id: str, chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			chunkrange: 
+			id: 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, id: str, chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			chunkrange: 
+			id: 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, ids: List[str], chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			chunkrange: 
+			ids: 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, centerX: int, centerZ: int, ids: List[str], chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			centerZ: 
+			centerX: 
+			chunkrange: 
+			ids: 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			blockFilter: 
+			stateFilter: 
+			chunkrange: 
+		"""
+		pass
+
+	@overload
+	def findBlocksMatching(self, chunkX: int, chunkZ: int, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[PositionCommon_Pos3D]:
+		"""
+		Since: 1.6.4 
+
+		Args:
+			blockFilter: 
+			stateFilter: 
+			chunkrange: 
+			chunkX: 
+			chunkZ: 
+		"""
+		pass
+
 	@overload
 	def getScoreboards(self) -> ScoreboardsHelper:
 		"""
@@ -84,6 +194,22 @@ An instance of this class is passed to scripts as the 'World' variable.
 		"""
 		pass
 
+	@overload
+	def rayTraceBlock(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int, fluid: bool) -> BlockDataHelper:
+		"""raytrace between two points returning the first block hit.\n
+		Since: 1.6.5 
+
+		Args:
+			z1: 
+			y1: 
+			z2: 
+			x1: 
+			y2: 
+			x2: 
+			fluid: 
+		"""
+		pass
+
 	@overload
 	def getDimension(self) -> str:
 		"""
