@@ -1,6 +1,6 @@
 from typing import overload
-from .History_HistoryStep import *
-from .SelectCursor import *
+from .History_HistoryStep import History_HistoryStep
+from .SelectCursor import SelectCursor
 
 
 class History_TabLines(History_HistoryStep):
