@@ -2,9 +2,9 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 
-ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine_net.minecraft.text.Text_"]
+ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine"]
 Text = TypeVar["net.minecraft.text.Text"]
-Predicate = TypeVar["java.util.function.Predicate_net.minecraft.client.gui.hud.ChatHudLine_net.minecraft.text.Text__"]
+Predicate = TypeVar["java.util.function.Predicate_net.minecraft.client.gui.hud.ChatHudLine_"]
 
 class IChatHud:
 
