@@ -34,7 +34,7 @@ class Inventory(Generic[T]):
 
 	@overload
 	def click(self, slot: int, mousebutton: int) -> "Inventory":
-		"""Clicks a slot with a mouse button.\n
+		"""Clicks a slot with a mouse button.~~if the slot is a container, it will click the first slot in the container\n
 		Since: 1.0.8 
 
 		Args:
@@ -105,6 +105,30 @@ It should be safe to chain these without FClient#waitTick() at least for a bunch
 		"""
 		pass
 
+	@overload
+	def quickAll(self, slot: int) -> int:
+		"""
+		Since: 1.7.0 
+
+		Args:
+			slot: 
+		"""
+		pass
+
+	@overload
+	def quickAll(self, slot: int, button: int) -> int:
+		"""quicks all that match the slot\n
+		Since: 1.7.0 
+
+		Args:
+			button: 
+			slot: a slot from the section you want to move items from 
+
+		Returns:
+			number of items that matched 
+		"""
+		pass
+
 	@overload
 	def getHeld(self) -> ItemStackHelper:
 		"""
@@ -166,7 +190,8 @@ It should be safe to chain these without FClient#waitTick() at least for a bunch
 
 	@overload
 	def swapHotbar(self, slot: int, hotbarSlot: int) -> "Inventory":
-		"""equivelent to hitting the numbers or f for swapping slots to hotbar
+		"""equivelent to hitting the numbers or f for swapping slots to hotbar\n
+		Since: 1.6.5 [citation needed] 
 
 		Args:
 			hotbarSlot: 0-8 or 40 for offhand 
