@@ -1,4 +1,5 @@
 from typing import overload
+from typing import List
 from .Inventory import Inventory
 
 
@@ -20,6 +21,16 @@ class LoomInventory(Inventory):
 		"""
 		pass
 
+	@overload
+	def listAvailablePatterns(self) -> List[str]:
+		"""
+		Since: 1.7.0 
+
+		Returns:
+			available pattern ids 
+		"""
+		pass
+
 	@overload
 	def selectPatternId(self, id: str) -> bool:
 		"""
