@@ -43,6 +43,15 @@ class Mappings:
 		"""
 		pass
 
+	@overload
+	def getClass(self, className: str) -> Mappings_MappedClass:
+		"""gets the class without instance, so can only access static methods/fields
+
+		Args:
+			className: 
+		"""
+		pass
+
 	pass
 
 
