@@ -5,9 +5,9 @@ from .IChatHud import IChatHud
 
 CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
 MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
-ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine_net.minecraft.text.Text_"]
+ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine"]
 Text = TypeVar["net.minecraft.text.Text"]
-Predicate = TypeVar["java.util.function.Predicate_net.minecraft.client.gui.hud.ChatHudLine_net.minecraft.text.Text__"]
+Predicate = TypeVar["java.util.function.Predicate_net.minecraft.client.gui.hud.ChatHudLine_"]
 
 class MixinChatHud(IChatHud):
 
