@@ -40,7 +40,7 @@ class MovementDummy(LivingEntity):
 		pass
 
 	@overload
-	def method_26318(self, movementInput: Vec3d, f: float) -> Vec3d:
+	def applyMovementInput(self, movementInput: Vec3d, f: float) -> Vec3d:
 		"""We have to do this "inject" since the the applyClimbingSpeed() method
 in LivingEntity is checking if we are a PlayerEntity, we want to apply the outcome of this check,
 so this is why we need to set the y-velocity to 0.
