@@ -1,5 +1,5 @@
 from typing import overload
-from .BaseLibrary import *
+from .BaseLibrary import BaseLibrary
 
 
 class PerLanguageLibrary(BaseLibrary):
