@@ -28,6 +28,23 @@ class PlayerListEntryHelper(BaseHelper):
 		"""
 		pass
 
+	@overload
+	def getPing(self) -> int:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def getGamemode(self) -> str:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			null if unknown 
+		"""
+		pass
+
 	@overload
 	def getDisplayText(self) -> TextHelper:
 		"""
