@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .ScriptTrigger import *
+from .ScriptTrigger import ScriptTrigger
 
 Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
 
