@@ -3,9 +3,9 @@ from typing import List
 from typing import TypeVar
 from typing import Mapping
 
+MutableText = TypeVar["net.minecraft.text.MutableText"]
 AbsVisitor = TypeVar["io.noties.prism4j.AbsVisitor"]
 Style = TypeVar["net.minecraft.text.Style"]
-LiteralText = TypeVar["net.minecraft.text.LiteralText"]
 
 class TextStyleCompiler(AbsVisitor):
 
@@ -14,7 +14,7 @@ class TextStyleCompiler(AbsVisitor):
 		pass
 
 	@overload
-	def getResult(self) -> List[LiteralText]:
+	def getResult(self) -> List[MutableText]:
 		pass
 
 	pass
